"use strict";
Object.defineProperty(exports, "__esModule", { value: !0 });
var sanity = require("sanity"), jsxRuntime = require("react/jsx-runtime"), react = require("react"), QRCode = require("react-qr-code"), styled = require("styled-components"), icons = require("@sanity/icons"), ui = require("@sanity/ui");
function _interopDefaultCompat(e) {
  return e && typeof e == "object" && "default" in e ? e : { default: e };
}
var QRCode__default = /* @__PURE__ */ _interopDefaultCompat(QRCode), styled__default = /* @__PURE__ */ _interopDefaultCompat(styled);
function Show({
  when,
  children,
  fallback
}) {
  return /* @__PURE__ */ jsxRuntime.jsx(jsxRuntime.Fragment, { children: when ? children : fallback });
}
const Offscreen = styled__default.default.div`
  position: fixed;
  top: 0;
  left: 0;
  transform: translate(-200%, -200%);
`, Context = react.createContext(() => {
});
function QRCodeConverter({
  value,
  options,
  children
}) {
  var _a;
  const qrCodeRef = react.useRef(), resolver = react.useCallback(() => {
    var _a2;
    return (_a2 = qrCodeRef.current) == null ? void 0 : _a2.outerHTML;
  }, []);
  return /* @__PURE__ */ jsxRuntime.jsxs(Context.Provider, { value: resolver, children: [
    /* @__PURE__ */ jsxRuntime.jsx(Show, { when: value, children: /* @__PURE__ */ jsxRuntime.jsx(Offscreen, { children: /* @__PURE__ */ jsxRuntime.jsx(
      QRCode__default.default,
      {
        ref: qrCodeRef,
        value,
        size: (_a = options.size) != null ? _a : 500,
        bgColor: options.bgColor,
        fgColor: options.fgColor,
        level: options.level
      }
    ) }) }),
    children
  ] });
}
function useQRCodeSVGMarkupResolver() {
  return react.useContext(Context);
}
function QRCodeGeneratorView({
  value,
  control,
  setValue,
  children
}) {
  return /* @__PURE__ */ jsxRuntime.jsxs(ui.Stack, { space: 5, children: [
    /* @__PURE__ */ jsxRuntime.jsxs(ui.Flex, { gap: 3, align: "center", children: [
      /* @__PURE__ */ jsxRuntime.jsx(ui.Container, { width: 100, children: /* @__PURE__ */ jsxRuntime.jsx(
        ui.TextInput,
        {
          type: "text",
          placeholder: "Write or paste value to encode",
          radius: 2,
          value,
          muted: !setValue,
          readOnly: !setValue,
          onChange: ({ currentTarget }) => {
            setValue == null || setValue(currentTarget.value);
          }
        }
      ) }),
      control
    ] }),
    /* @__PURE__ */ jsxRuntime.jsx(sanity.FormField, { children })
  ] });
}
var Status = /* @__PURE__ */ ((Status2) => (Status2[Status2.Idle = 0] = "Idle", Status2[Status2.Uploading = 1] = "Uploading", Status2[Status2.Uploaded = 2] = "Uploaded", Status2[Status2.Failed = 3] = "Failed", Status2))(Status || {});
function useQRCodeUploader() {
  const timer = react.useRef(), toast = ui.useToast(), client = sanity.useClient({ apiVersion: "2021-06-07" }), documentId = sanity.useFormValue(["_id"]), getSVGMarkup = useQRCodeSVGMarkupResolver(), [status, setStatus] = react.useState(
    0
    /* Idle */
  ), uploader = async (fieldName, fileNameSuffix) => {
    const svgMarkup = getSVGMarkup();
    if (!(!svgMarkup || status === 1)) {
      setStatus(
        1
        /* Uploading */
      );
      try {
        const imageAsset = await client.assets.upload(
          "image",
          new Blob([svgMarkup], { type: "image/svg+xml" }),
          {
            filename: `qr-code-to-${fileNameSuffix}`
          }
        );
        await client.patch(documentId).set({
          [fieldName]: {
            _type: "image",
            asset: {
              _type: "reference",
              _ref: imageAsset._id
            }
          }
        }).commit(), setStatus(
          2
          /* Uploaded */
        ), toast.push({
          status: "success",
          title: "QR code successfully added to your assets"
        });
      } catch {
        setStatus(
          3
          /* Failed */
        ), toast.push({
          status: "error",
          title: "Oooops, something went wrong"
        });
      }
    }
  };
  return [status, (fieldName, fileNameSuffix) => {
    clearTimeout(timer.current), timer.current = self.setTimeout(uploader, 200, fieldName, fileNameSuffix);
  }];
}
function ManualQRCodeGenerator({
  value,
  setValue,
  children,
  fieldName
}) {
  const [uploadingStatus, startUploading] = useQRCodeUploader();
  return /* @__PURE__ */ jsxRuntime.jsx(
    QRCodeGeneratorView,
    {
      value,
      setValue,
      control: /* @__PURE__ */ jsxRuntime.jsx(
        ui.Tooltip,
        {
          content: /* @__PURE__ */ jsxRuntime.jsx(ui.Container, { width: 0, padding: 2, children: /* @__PURE__ */ jsxRuntime.jsx(ui.Text, { children: "The uploading is still in progress. Please wait until it finishes and then you can regenerate the QR code again." }) }),
          disabled: uploadingStatus !== Status.Uploading,
          fallbackPlacements: ["bottom", "left", "right"],
          placement: "top",
          portal: !0,
          children: /* @__PURE__ */ jsxRuntime.jsx(
            ui.Button,
            {
              icon: icons.GenerateIcon,
              loading: uploadingStatus === Status.Uploading,
              text: "Generate QR",
              fontSize: 2,
              padding: 3,
              onClick: () => {
                startUploading(fieldName, value);
              },
              style: { cursor: "pointer" },
              tone: "primary"
            }
          )
        }
      ),
      children
    }
  );
}
function DependentQRCodeGenerator({
  value,
  options,
  setValue,
  fieldName,
  children
}) {
  const firstRun = react.useRef(!0), dependency = String(
    sanity.useFormValue([].concat(options.dependOn))
  ), [, startUploading] = useQRCodeUploader();
  return react.useEffect(() => {
    dependency && (setValue(dependency), firstRun.current || startUploading(fieldName, dependency)), firstRun.current = !1;
  }, [dependency]), /* @__PURE__ */ jsxRuntime.jsx(QRCodeGeneratorView, { value, children });
}
var QRCodeGenerator$1 = (props) => {
  const [value, setValue] = react.useState("");
  return /* @__PURE__ */ jsxRuntime.jsx(QRCodeConverter, { value, options: props.schemaType.options, children: /* @__PURE__ */ jsxRuntime.jsx(
    Show,
    {
      when: props.schemaType.options.dependOn,
      fallback: /* @__PURE__ */ jsxRuntime.jsx(
        ManualQRCodeGenerator,
        {
          value,
          setValue,
          fieldName: props.elementProps.id,
          children: props.renderDefault(props)
        }
      ),
      children: /* @__PURE__ */ jsxRuntime.jsx(
        DependentQRCodeGenerator,
        {
          value,
          options: props.schemaType.options,
          setValue,
          fieldName: props.elementProps.id,
          children: props.renderDefault(props)
        }
      )
    }
  ) });
};
const qrCodeType = sanity.defineType({
  name: "qrCode",
  type: "image",
  title: "QR Code Generator",
  components: { input: QRCodeGenerator$1 }
}), QRCodeGenerator = sanity.definePlugin(
  () => ({
    name: "sanity-plugin-qr-code-generator",
    schema: { types: [qrCodeType] }
  })
), QrCodeGenerator = QRCodeGenerator;
exports.QRCodeGenerator = QRCodeGenerator;
exports.QrCodeGenerator = QrCodeGenerator;
//# sourceMappingURL=index.cjs.map
