import { FormField, useClient, useFormValue, defineType, definePlugin } from "sanity";
import { jsx, Fragment, jsxs } from "react/jsx-runtime";
import { createContext, useRef, useCallback, useContext, useState, useEffect } from "react";
import QRCode from "react-qr-code";
import styled from "styled-components";
import { GenerateIcon } from "@sanity/icons";
import { Stack, Flex, Container, TextInput, useToast, Tooltip, Text, Button } from "@sanity/ui";
function Show({
  when,
  children,
  fallback
}) {
  return /* @__PURE__ */ jsx(Fragment, { children: when ? children : fallback });
}
const Offscreen = styled.div`
  position: fixed;
  top: 0;
  left: 0;
  transform: translate(-200%, -200%);
`, Context = createContext(() => {
});
function QRCodeConverter({
  value,
  options,
  children
}) {
  var _a;
  const qrCodeRef = useRef(), resolver = useCallback(() => {
    var _a2;
    return (_a2 = qrCodeRef.current) == null ? void 0 : _a2.outerHTML;
  }, []);
  return /* @__PURE__ */ jsxs(Context.Provider, { value: resolver, children: [
    /* @__PURE__ */ jsx(Show, { when: value, children: /* @__PURE__ */ jsx(Offscreen, { children: /* @__PURE__ */ jsx(
      QRCode,
      {
        ref: qrCodeRef,
        value,
        size: (_a = options.size) != null ? _a : 500,
        bgColor: options.bgColor,
        fgColor: options.fgColor,
        level: options.level
      }
    ) }) }),
    children
  ] });
}
function useQRCodeSVGMarkupResolver() {
  return useContext(Context);
}
function QRCodeGeneratorView({
  value,
  control,
  setValue,
  children
}) {
  return /* @__PURE__ */ jsxs(Stack, { space: 5, children: [
    /* @__PURE__ */ jsxs(Flex, { gap: 3, align: "center", children: [
      /* @__PURE__ */ jsx(Container, { width: 100, children: /* @__PURE__ */ jsx(
        TextInput,
        {
          type: "text",
          placeholder: "Write or paste value to encode",
          radius: 2,
          value,
          muted: !setValue,
          readOnly: !setValue,
          onChange: ({ currentTarget }) => {
            setValue == null || setValue(currentTarget.value);
          }
        }
      ) }),
      control
    ] }),
    /* @__PURE__ */ jsx(FormField, { children })
  ] });
}
var Status = /* @__PURE__ */ ((Status2) => (Status2[Status2.Idle = 0] = "Idle", Status2[Status2.Uploading = 1] = "Uploading", Status2[Status2.Uploaded = 2] = "Uploaded", Status2[Status2.Failed = 3] = "Failed", Status2))(Status || {});
function useQRCodeUploader() {
  const timer = useRef(), toast = useToast(), client = useClient({ apiVersion: "2021-06-07" }), documentId = useFormValue(["_id"]), getSVGMarkup = useQRCodeSVGMarkupResolver(), [status, setStatus] = useState(
    0
    /* Idle */
  ), uploader = async (fieldName, fileNameSuffix) => {
    const svgMarkup = getSVGMarkup();
    if (!(!svgMarkup || status === 1)) {
      setStatus(
        1
        /* Uploading */
      );
      try {
        const imageAsset = await client.assets.upload(
          "image",
          new Blob([svgMarkup], { type: "image/svg+xml" }),
          {
            filename: `qr-code-to-${fileNameSuffix}`
          }
        );
        await client.patch(documentId).set({
          [fieldName]: {
            _type: "image",
            asset: {
              _type: "reference",
              _ref: imageAsset._id
            }
          }
        }).commit(), setStatus(
          2
          /* Uploaded */
        ), toast.push({
          status: "success",
          title: "QR code successfully added to your assets"
        });
      } catch {
        setStatus(
          3
          /* Failed */
        ), toast.push({
          status: "error",
          title: "Oooops, something went wrong"
        });
      }
    }
  };
  return [status, (fieldName, fileNameSuffix) => {
    clearTimeout(timer.current), timer.current = self.setTimeout(uploader, 200, fieldName, fileNameSuffix);
  }];
}
function ManualQRCodeGenerator({
  value,
  setValue,
  children,
  fieldName
}) {
  const [uploadingStatus, startUploading] = useQRCodeUploader();
  return /* @__PURE__ */ jsx(
    QRCodeGeneratorView,
    {
      value,
      setValue,
      control: /* @__PURE__ */ jsx(
        Tooltip,
        {
          content: /* @__PURE__ */ jsx(Container, { width: 0, padding: 2, children: /* @__PURE__ */ jsx(Text, { children: "The uploading is still in progress. Please wait until it finishes and then you can regenerate the QR code again." }) }),
          disabled: uploadingStatus !== Status.Uploading,
          fallbackPlacements: ["bottom", "left", "right"],
          placement: "top",
          portal: !0,
          children: /* @__PURE__ */ jsx(
            Button,
            {
              icon: GenerateIcon,
              loading: uploadingStatus === Status.Uploading,
              text: "Generate QR",
              fontSize: 2,
              padding: 3,
              onClick: () => {
                startUploading(fieldName, value);
              },
              style: { cursor: "pointer" },
              tone: "primary"
            }
          )
        }
      ),
      children
    }
  );
}
function DependentQRCodeGenerator({
  value,
  options,
  setValue,
  fieldName,
  children
}) {
  const firstRun = useRef(!0), dependency = String(
    useFormValue([].concat(options.dependOn))
  ), [, startUploading] = useQRCodeUploader();
  return useEffect(() => {
    dependency && (setValue(dependency), firstRun.current || startUploading(fieldName, dependency)), firstRun.current = !1;
  }, [dependency]), /* @__PURE__ */ jsx(QRCodeGeneratorView, { value, children });
}
var QRCodeGenerator$1 = (props) => {
  const [value, setValue] = useState("");
  return /* @__PURE__ */ jsx(QRCodeConverter, { value, options: props.schemaType.options, children: /* @__PURE__ */ jsx(
    Show,
    {
      when: props.schemaType.options.dependOn,
      fallback: /* @__PURE__ */ jsx(
        ManualQRCodeGenerator,
        {
          value,
          setValue,
          fieldName: props.elementProps.id,
          children: props.renderDefault(props)
        }
      ),
      children: /* @__PURE__ */ jsx(
        DependentQRCodeGenerator,
        {
          value,
          options: props.schemaType.options,
          setValue,
          fieldName: props.elementProps.id,
          children: props.renderDefault(props)
        }
      )
    }
  ) });
};
const qrCodeType = defineType({
  name: "qrCode",
  type: "image",
  title: "QR Code Generator",
  components: { input: QRCodeGenerator$1 }
}), QRCodeGenerator = definePlugin(
  () => ({
    name: "sanity-plugin-qr-code-generator",
    schema: { types: [qrCodeType] }
  })
), QrCodeGenerator = QRCodeGenerator;
export {
  QRCodeGenerator,
  QrCodeGenerator
};
//# sourceMappingURL=index.esm.js.map
